#
# spec file for package cookiecutter
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2017 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           cookiecutter
Version:        2.6.0
Release:        3.1
Summary:        A command-line utility that creates projects from project templates
License:        BSD-3-Clause
URL:            https://github.com/audreyr/cookiecutter
Source:         https://github.com/cookiecutter/cookiecutter/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# recent versions are not published on PyPI: https://github.com/cookiecutter/cookiecutter/issues/1636
#Source:         https://files.pythonhosted.org/packages/source/c/cookiecutter/cookiecutter-%%{version}.tar.gz
Source1:        ccext.py
BuildRequires:  %{python_module Jinja2 >= 2.7 with %python-Jinja2 < 4}
BuildRequires:  %{python_module arrow}
BuildRequires:  %{python_module binaryornot >= 0.2.0}
BuildRequires:  %{python_module click >= 7 with %python-click < 9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-slugify}
BuildRequires:  %{python_module rich}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  python-rpm-macros
Requires:       git-core
Requires:       python-PyYAML
Requires:       python-arrow
Requires:       python-binaryornot >= 0.2.0
Requires:       python-python-slugify
Requires:       python-requests >= 2.18.0
Requires:       python-rich
Requires:       (python-Jinja2 >= 2.7 with python-Jinja2 < 4)
Requires:       (python-click >= 7 with python-click < 9)
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION Testing requirements
BuildRequires:  %{python_module chardet >= 2.0.0}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.18.0}
# /SECTION
# SECTION Documentation requirements
BuildRequires:  python3-Sphinx
BuildRequires:  python3-myst-parser
BuildRequires:  python3-sphinx-autodoc-typehints
BuildRequires:  python3-sphinx-click
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  python3-sphinxcontrib-apidoc
# /SECTION
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
Provides:       cookiecutter = %{version}-%{release}
Obsoletes:      cookiecutter < %{version}-%{release}
%endif
%python_subpackages

%package -n cookiecutter-doc
Summary:        Documentation files for %{name}

%description
A command-line utility that creates projects from cookiecutters (project
templates), e.g. creating a Python package project from a Python package
project template.

Project templates can be in any programming language or markup format.

%description -n cookiecutter-doc
A command-line utility that creates projects from cookiecutters (project
templates), e.g. creating a Python package project from a Python package
project template.

This package contains the documentation for cookiecutter.

%prep
%autosetup -p1 -n cookiecutter-%{version}
cp %{SOURCE1} docs
# Remove pytest addopts:
rm setup.cfg

%build
%pyproject_wheel
pushd docs
sphinx-build -b html -d .build/doctrees . _build/html
rm _build/html/.buildinfo
popd

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/cookiecutter
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# the doc directive in the files section cannot deduplicate, so do it manually
mkdir -p %{buildroot}%{_docdir}/cookiecutter-doc
cp -r docs/_build/html %{buildroot}%{_docdir}/cookiecutter-doc/
%fdupes %{buildroot}%{_docdir}/cookiecutter-doc

%check
export LC_ALL=en_US.UTF-8
export LANG=en_US.UTF-8
# test_generate_file_verbose_template_syntax_error: reported at https://github.com/cookiecutter/cookiecutter/issues/1655
%pytest tests -k 'not test_generate_file_verbose_template_syntax_error'

%pre
# delete command if the old package was not update-alternatives controlled
[ -h %{_bindir}/cookiecutter ] || rm -f %{_bindir}/cookiecutter

%post
%python_install_alternative cookiecutter

%postun
%python_uninstall_alternative cookiecutter

%files %{python_files}
%license LICENSE
%python_alternative cookiecutter
%{python_sitelib}/cookiecutter
%{python_sitelib}/cookiecutter-%{version}.dist-info

%files -n cookiecutter-doc
%license LICENSE
%doc %{_docdir}/cookiecutter-doc

%changelog
* Mon Jan 20 2025 Sebastian Wagner <sebix@sebix.at>
- Add python3-sphinx_rtd_theme as build dependency to fix the doc build fail.
* Fri Jan 17 2025 Steve Kowalik <steven.kowalik@suse.com>
- Drop unneeded BuildRequires on recommonmark, it was dropped back in
  2.2.0.
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 2.6.0:
  * Support Python 3.12
  * Modifying Jinja2 start and end variable strings (#1997)
  * Fix regression #2009: Adding value to nested dicts broken
  * Fixed errors caused by invalid config files. (#1995)
  * Default values can be passed as a dict (#1924)
  * Implement new style for nested templates config (#1981)
  * Fix FileExistsError when using a relative template path
  * Fix recursive context overwrites
  * Gracefully handle files with mixed lined endings (#1942)
  * Implement a pre_prompt hook that will run before prompts
  * Implement a pre_prompt hook that will run before prompts
  * update main docstrings to include overwrite_if_exists and
    skip_if_file_exists
  * add checkout details to the context (fixes #1759) (#1923)
  * Fix nested templates in Git repository (#1922)
  * Fix prompt counter. (#1940)
  * Fix variables with null default not being required (#1919)
* Thu Sep  7 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.3.0:
  * Improve style of prompts using `rich` (#1901) @vemonet
  * Fix replay (#1904) @vemonet
  * Support multichoice overwrite (#1903) @Meepit
- Switch to pyproject macro.
* Sun Jul 16 2023 Sebastian Wagner <sebix@sebix.at>
- update to version 2.2.3:
  - Changes:
  - Minor Changes:
  - Add support for adding human-readable labels for choices when defining multiple choices questions (#1898) @vemonet
  - Prompt with replay file (#1758) @w1ndblow
  - CI/CD and QA changes:
  - Set cookiecutter/VERSION.txt as source of truth for version number (#1896) @ericof
  - [pre-commit.ci] pre-commit autoupdate (#1897) @pre-commit-ci
  - Bugfixes:
  - Fix issue where the prompts dict was not passed for yes_no questions (#1895) @vemonet
  - Set cookiecutter/VERSION.txt as source of truth for version number (#1896) @ericof
- update to version 2.2.2:
  - CI/CD and QA changes:
  - Improve gitignore (#1889) @audreyfeldroy
  - Add warning for jinja2_time (#1890) @henryiii
- update to version 2.2.0:
  - Changes:
  - Added timeout on request.get() for ensuring that if a recipient serve… (#1772) @openrefactory
  - Fixing Carriage Return Line Feed (CRLF) order in docs #1792 (#1793) @Lahiry
  - Reduce I/O (#1877) @kurtmckee
  - Remove a pre-commit hook special case (#1875) @kurtmckee
  - Remove universal bdist_wheel option; use "python -m build" (#1739) @mwtoews
  - Remove unused import from post-generate hook script example (#1795) @KAZYPinkSaurus
  - Standardize newlines for all platforms (#1870) @kurtmckee
  - feat: Add resolved template repository path as _repo_dir to the context (#1771) @tmeckel
  - Minor Changes:
  - Added support for providing human-readable prompts to the different variables (#1881) @vemonet
  - Added: Boolean variable support in JSON (#1626) @liortct
  - Added: CLI option to keep project files on failure. (#1669) @MaciejPatro
  - Added: Support partially overwrite keys in nested dict (#1692) @cksac
  - Added: Templates inheritance (#1485) @simobasso
  - Code quality: Tests upgrade: Use pathlib for files read/write (#1718) @insspb
  - Inline jinja2-time extension code (#1779) @tranzystorek-io
  - Support Python 3.11 (#1850) @kurtmckee
  - Support nested config files (#1770) @dariocurr
  - preserves original options in `_cookiecutter` (#1874) @kjaymiller
  - CI/CD and QA changes:
  - Add a Dependabot config to autoupdate GitHub workflow actions (#1851) @kurtmckee
  - Added: Readthedocs build config (#1707) @insspb
  - Bump actions/setup-python from 3 to 4 (#1854) @dependabot
  - Bump paambaati/codeclimate-action from 3.0.0 to 4.0.0 (#1853) @dependabot
  - CI/CD: Tox -> Nox: Added nox configuration (#1706) @insspb
  - CI/CD: Tox -> Nox: Github actions definition minimized + Sync nox and github actions (#1714) @insspb
  - CI/CD: Tox -> Nox: Makefile update: Removed watchmedo and sed dependency, tox replaced with nox (#1713) @insspb
  - CI/CD: Updated .pre-commit-config.yaml to use latest hooks versions (#1712) @insspb
  - Code quality: Core files: Added exception reason reraise when exception class changed (PEP 3134) (#1719) @insspb
  - Code quality: Tests upgrade: Use pathlib for files read/write (#1718) @insspb
  - Code quality: core files: Format replaced with f-strings (#1716) @insspb
  - Code quality: find.py refactored and type annotated (#1721) @insspb
  - Code quality: tests files: Simplify statements fixes (#1717) @insspb
  - Code quality: utils.make_sure_path_exists refactored and type annotated (#1722) @insspb
  - Fixed: recommonmark replaced with myst, as recommonmark is deprecated (#1709) @insspb
  - Pretty-format JSON files (#1864) @kurtmckee
  - Rename `master` to `main` so CI runs correctly on merge (#1852) @kurtmckee
  - Standardize EOF newlines (#1876) @kurtmckee
  - Update `.gitignore` and cite where it was copied from (#1879) @kurtmckee
  - Update base docs, remove tox (#1858) @ericof
  - Update pre-commit hook versions (#1849) @kurtmckee
  - Updated: Release drafter configuration (#1704) @insspb
  - Use tox (#1866) @kurtmckee
  - Verify an expected warning is raised (#1869) @kurtmckee
  - fixed failing lint ci action by updating repo of flake8 (#1838) @Tamronimus
  - Documentation updates:
  - Add jinja env docs (#1872) @pamelafox
  - Documentation extension: Create a Cookiecutter From Scratch tutorial (#1592) @miro-jelaska
  - Easy PR! Fix typos and add minor doc updates (#1741) @Alex0Blackwell
  - Expand cli documentation relating to the no-input flag (#1543) (#1587) @jeremyswerdlow
  - Fix @audreyr to @audreyfeldroy github account rename (#1604) @ri0t
  - Fixed broken links to jinja docs (#1691) @insspb
  - Fixed minor typos in docs (#1753) @segunb
  - Fixed: Python code block in the replay documentation (#1715) @juhannc
  - Fixed: recommonmark replaced with myst, as recommonmark is deprecated (#1709) @insspb
  - Improve Docs Readability (#1690) @ryanrussell
  - Update base docs, remove tox (#1858) @ericof
  - Updated: Boolean Variables documentation and docstrings (#1705) @italomaia
  - docs: fix simple typo, shat -> that (#1749) @timgates42
  - fixing badge display problem (#1798) @Paulokim1
  - Bugfixes:
  - Fixed the override not working with copy only dir #1650 (#1651) @zhongdai
  - Fixed: Removed mention of packages versions, to exclude dependabot warnings alerts (#1711) @insspb
  - cleanup files if panics during hooks - bugfix (#1760) @liortct
* Thu May 11 2023 Johannes Kastl <kastl@b1-systems.de>
- fix leftover python3 BuildRequires and use the python_module
  macros. This allows builds on SLE15 with python3.11
* Wed May 10 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Tue Jun 21 2022 Sebastian Wagner <sebix@sebix.at>
- remove obsolete patch cookiecutter-fix-setup.patch
- update to version 2.1.1:
  - Documentation updates:
  - Fix local extensions documentation (#1686)
  - Bugfixes:
  - Sanitize Mercurial branch information before checkout. (#1689)
- update to version 2.1.0:
  - Changes:
  - Move contributors and backers to credits section (#1599)
  - test_generate_file_verbose_template_syntax_error fixed (#1671)
  - Removed changes related to setuptools_scm (#1629)
  - Feature/local extensions (#1240)
  - CI/CD and QA changes:
  - Check manifest: pre-commit, fixes, cleaning (#1683)
  - Follow PyPA guide to release package using GitHub Actions. (#1682)
  - Documentation updates:
  - Fix typo in dict_variables.rst (#1680)
  - Documentation overhaul (#1677)
  - Fixed incorrect link on docs. (#1649)
  - Bugfixes:
  - Restore accidentally deleted support for click 8.x (#1643)
* Sun Apr 24 2022 Ben Greiner <code@bnavigator.de>
- update fix-setup-version.patch to cookiecutter-fix-setup.patch
  gh#cookiecutter/cookiecutter#1656
- Sync rpm requirements metadata to setuptools generated metadata
* Mon Apr  4 2022 Sebastian Wagner <sebix@sebix.at>
- add fix-setup-version.patch to fix the version in setup.py
* Mon Mar 28 2022 Sebastian Wagner <sebix@sebix.at>
- update to version 2.0.2:
  - Fix Python version number in cookiecutter --version and test on Python 3.10 (#1621) @ozer550
  - Removed changes related to setuptools_scm (#1629) @audreyfeldroy @ozer550
- update to version 2.0.1:
  - Breaking Changes:
  - Release preparation for 2.0.1rc1 (#1608) @audreyfeldroy
  - Replace poyo with pyyaml. (#1489) @dHannasch
  - Added: Path templates will be rendered when copy_without_render used (#839) @noirbizarre
  - Added: End of line detection and configuration. (#1407) @insspb
  - Remove support for python2.7 (#1386) @ssbarnea
  - Minor Changes:
  - Adopt setuptools-scm packaging (#1577) @ssbarnea
  - Log the error message when git clone fails, not just the return code (#1505) @logworthy
  - allow jinja 3.0.0 (#1548) @wouterdb
  - Added uuid extension to be able to generate uuids (#1493) @jonaswre
  - Alert user if choice is invalid (#1496) @dHannasch
  - Replace poyo with pyyaml. (#1489) @dHannasch
  - update AUTHOR lead (#1532) @HosamAlmoghraby
  - Add Python 3.9 (#1478) @gliptak
  - Added: --list-installed cli option, listing already downloaded cookiecutter packages (#1096) @chrisbrake
  - Added: Jinja2 Environment extension on files generation stage (#1419) @insspb
  - Added: --replay-file cli option, for replay file distributing (#906) @Cadair
  - Added: _output_dir to cookiecutter context (#1034) @Casyfill
  - Added: CLI option to ignore hooks (#992) @rgreinho
  - Changed: Generated projects can use multiple type hooks at same time. (sh + py) (#974) @milonimrod
  - Added: Path templates will be rendered when copy_without_render used (#839) @noirbizarre
  - Added: End of line detection and configuration. (#1407) @insspb
  - Making code python 3 only: Remove python2 u' sign, fix some strings (#1402) @insspb
  - py3: remove futures, six and encoding (#1401) @insspb
  - Render variables starting with an underscore. (#1339) @smoothml
  - Tests refactoring: test_utils write issues fixed #1405 (#1406) @insspb
  - CI/CD and QA changes:
  - enable branch coverage (#1542) @simobasso
  - Make release-drafter diff only between master releases (#1568) @SharpEdgeMarshall
  - ensure filesystem isolation during tests execution (#1564) @simobasso
  - add safety ci step (#1560) @simobasso
  - pre-commit: add bandit hook (#1559) @simobasso
  - Replace tmpdir in favour of tmp_path (#1545) @SharpEdgeMarshall
  - Fix linting in CI (#1546) @SharpEdgeMarshall
  - Coverage 100%% (#1526) @SharpEdgeMarshall
  - Run coverage with matrix (#1521) @SharpEdgeMarshall
  - Lint rst files (#1443) @ssbarnea
  - Python3: Changed io.open to build-in open (PEP3116) (#1408) @insspb
  - Making code python 3 only: Remove python2 u' sign, fix some strings (#1402) @insspb
  - py3: remove futures, six and encoding (#1401) @insspb
  - Removed: Bumpversion, setup.py arguments. (#1404) @insspb
  - Tests refactoring: test_utils write issues fixed #1405 (#1406) @insspb
  - Added: Automatic PyPI deploy on tag creation (#1400) @insspb
  - Changed: Restored coverage reporter (#1399) @insspb
  - Documentation updates:
  - Fix pull requests checklist reference (#1537) @glumia
  - Fix author name (#1544) @HosamAlmoghraby
  - Add missing contributors (#1535) @glumia
  - Update CONTRIBUTING.md (#1529) @glumia
  - Update LICENSE (#1519) @simobasso
  - docs: rewrite the conditional files / directories example description. (#1437) @lyz-code
  - Fix incorrect years in release history (#1473) @graue70
  - Add slugify in the default extensions list (#1470) @oncleben31
  - Renamed cookiecutter.package to API (#1442) @grrlic
  - Fixed wording detail (#1427) @steltenpower
  - Changed: CLI Commands documentation engine (#1418) @insspb
  - Added: Example for conditional files / directories in hooks (#1397) @xyb
  - Changed: README.md PyPI URLs changed to the modern PyPI last version (#1391) @brettcannon
  - Fixed: Comma in README.md (#1390) @Cy-dev-tex
  - Fixed: Replaced no longer maintained pipsi by pipx (#1395) @ndclt
  - Bugfixes:
  - Add support for click 8.x (#1569) @cjolowicz
  - Force click<8.0.0 (#1562) @SharpEdgeMarshall
  - Remove direct dependency on markupsafe (#1549) @ssbarnea
  - fixes prompting private rendered dicts (#1504) @juhuebner
  - User's JSON parse error causes ugly Python exception #809 (#1468) @noone234
  - config: set default on missing default_context key (#1516) @simobasso
  - Fixed: Values encoding on Windows (#1414) @agateau
  - Fixed: Fail with gitolite repositories (#1144) @javiersanp
  - MANIFEST: Fix file name extensions (#1387) @sebix
  - Deprecations:
  - Removed: Bumpversion, setup.py arguments. (#1404) @insspb
  - Removed support for Python 3.6 and PyPy (#1608) @audreyfeldroy
* Sat May 15 2021 Ben Greiner <code@bnavigator.de>
- Make cookiecutter usable by all python3X flavors
* Fri May 14 2021 Sebastian Wagner <sebix@sebix.at>
- update to version 1.7.3:
  - Fixed jinja2 and markupsafe dependencies
* Wed Jan 20 2021 John Vandenberg <jayvdb@gmail.com>
- Changed dependency from git to git-core
- Remove build dependency on pytest-cov and python-devel
- Use fdupes
* Wed Apr 22 2020 Sebastian Wagner <sebix@sebix.at>
- add python3-python-slugify as new dependency, fixes build.
- update to version 1.7.2:
  * Fixed: Jinja2&Six version limits causing build errors with ansible project [@insspb](https://github.com/insspb) (#1385)
- update to version 1.7.1:
  This release was focused on internal code and CI/CD changes. During this release
  all code was verified to match pep8, pep257 and other code-styling guides.
  Project CI/CD was significantly changed, Windows platform checks based on Appveyor
  engine was replaced by GitHub actions tests. Appveyor was removed. Also our
  CI/CD was extended with Mac builds, to verify project builds on Apple devices.
  * Important Changes:
  * Added: Added debug messages for get_user_config [@ssbarnea](https://github.com/ssbarnea) (#1357)
  * Multiple templates per one repository feature added. [@RomHartmann](https://github.com/RomHartmann) (#1224, #1063)
  * Update replay.py json.dump indent for easy viewing [@nicain](https://github.com/nicain) (#1293)
  * 'future' library replaced with 'six' as a more lightweight python porting library [@asottile](https://github.com/asottile) (#941)
  * Added extension: Slugify template filter [@ppanero](https://github.com/ppanero) (#1336)
  * Added command line option: `--skip-if-file-exists`, allow to skip the existing files when doing `overwrite_if_exists`. [@chhsiao1981](https://github.com/chhsiao1981) (#1076)
  * Some packages versions limited to be compatible with python2.7 and python 3.5 [@insspb](https://github.com/insspb) (#1349)
  * Internal CI/CD and tests changes:
  * Coverage comment in future merge requests disabled [@ssbarnea](https://github.com/ssbarnea) (#1279)
  * Fixed Python 3.8 travis tests and setup.py message [@insspb](https://github.com/insspb) (#1295, #1297)
  * Travis builds extended with Windows setup for all supported python versions [@insspb](https://github.com/insspb) (#1300, #1301)
  * Update .travis.yml to be compatible with latest travis cfg specs [@luzfcb](https://github.com/luzfcb) (#1346)
  * Added new test to improve tests coverage [@amey589](https://github.com/amey589) (#1023)
  * Added missed coverage lines highlight to pytest-coverage report [@insspb](https://github.com/insspb) (#1352)
  * pytest-catchlog package removed from test_requirements, as now it is included in pytest [@insspb](https://github.com/insspb) (#1347)
  * Fixed `cov-report` tox invocation environment [@insspb](https://github.com/insspb) (#1350)
  * Added: Release drafter support and configuration to exclude changelog update work and focus on development [@ssbarnea](https://github.com/ssbarnea) [@insspb](https://github.com/insspb) (#1356, #1362)
  * Added: CI/CD steps for Github actions to speedup CI/CD [@insspb](https://github.com/insspb) (#1360)
  * Removed: Appveyor CI/CD completely removed [@insspb](https://github.com/insspb) [@ssbarnea](https://github.com/ssbarnea) [@insspb](https://github.com/insspb) (#1363, #1367)
  * Code style and docs changes:
  * Added black formatting verification on lint stage + project files reformatting [@ssbarnea](https://github.com/ssbarnea) [@insspb](https://github.com/insspb) (#1368)
  * Added pep257 docstring for tests/* files [@insspb](https://github.com/insspb) (#1369, #1370, #1371, #1372, #1373, #1374, #1375, #1376, #1377, #1378, #1380, #1381)
  * Added pep257 docstring for tests/conftests.py [@kishan](https://github.com/kishan3) (#1272, #1263)
  * Added pep257 docstring for tests/replay/conftest.py [@kishan](https://github.com/kishan3) (#1270, #1268)
  * Added pep257 docstring for docs/__init__.py [@kishan](https://github.com/kishan3) (#1273, #1265)
  * Added missing docstring headers to all files [@croesnick](https://github.com/croesnick) (#1269, #1283)
  * Gitter links replaced by Slack in README [@browniebroke](https://github.com/browniebroke) (#1282)
  * flake8-docstrings tests added to CI/CD [@ssbarnea](https://github.com/ssbarnea) (#1284)
  * Activated pydocstyle rule: D401 - First line should be in imperative mood [@ssbarnea](https://github.com/ssbarnea) (#1285)
  * Activated pydocstyle rule: D200 - One-line docstring should fit on one line with quotes [@ssbarnea](https://github.com/ssbarnea) (#1288)
  * Activated pydocstyle rule: D202 - No blank lines allowed after function docstring [@ssbarnea](https://github.com/ssbarnea) (#1288)
  * Activated pydocstyle rule: D205 - 1 blank line required between summary line and description [@ssbarnea](https://github.com/ssbarnea) (#1286, #1287)
  * Activated pydocstyle rule: ABS101 [@ssbarnea](https://github.com/ssbarnea) (#1288)
  * Replaced click documentation links to point to version 7 [@igorbasko01](https://github.com/igorbasko01) (#1303)
  * Updated submodule link to latest version with documentation links fix [@DanBoothDev](https://github.com/DanBoothDev) (#1388)
  * Fixed links in main README file. [@insspb](https://github.com/insspb) (#1342)
  * Fix indentation of .cookiecutterrc in README.md [@mhsekhavat](https://github.com/mhsekhavat) (#1322)
  * Changed format of loggers invocation [@insspb](https://github.com/insspb) (#1307)
- remove patch fix-click-711.patch, merged upstream.
* Fri Apr  3 2020 Sebastian Wagner <sebix@sebix.at>
- add fix-click-711.patch to fix compatibility with click 7.1.1 which fixes the tests which fixes the build.
* Wed Jan  1 2020 Sebastian Wagner <sebix@sebix.at>
- remove obsolete patch fix-python-invocation-tests.diff
- remove obsolete patch cookiecutter-click7.patch
- update to version 1.7.0:
  * Important Changes:
  * Drop support for EOL Python 3.4, thanks to [@jamescurtin](https://github.com/jamescurtin) and [@insspb](https://github.com/insspb) (#1024)
  * Drop support for EOL Python 3.3, thanks to [@hugovk](https://github.com/hugovk) (#1024)
  * Increase the minimum click version to 7.0, thanks to [@rly](https://github.com/rly) and [@luzfcb](https://github.com/luzfcb) (#1168)
  * Other Changes:
  * PEP257 fixing docstrings in exceptions.py. Thanks to [@MinchinWeb](https://github.com/MinchinWeb) (#1237)
  * PEP257 fixing docstrings in replay.py. Thanks to [@kishan](https://github.com/kishan3) (#1234)
  * PEP257 fixing docstrings in test_unzip.py. Thanks to [@tonytheleg](https://github.com/tonytheleg) and [@insspb](https://github.com/insspb) (#1236, #1262)
  * Fixed tests sequence for appveyor, to exclude file not found bug. Thanks to [@insspb](https://github.com/insspb) (#1257)
  * Updates REAMDE.md with svg badge for appveyor. Thanks to [@sobolevn](https://github.com/sobolevn) (#1254)
  * Add missing {%% endif %%} to Choice Variables example. Thanks to [@mattstibbs](https://github.com/mattstibbs) (#1249)
  * Core documentation converted to Markdown format thanks to [@wagnernegrao](https://github.com/wagnernegrao), [@insspb](https://github.com/insspb) (#1216)
  * Tests update: use sys.executable when invoking python in python 3 only environment thanks to [@vincentbernat](https://github.com/vincentbernat) (#1221)
  * Prevent `click` API v7.0 from showing choices when already shown, thanks to [@rly](https://github.com/rly) and [@luzfcb](https://github.com/luzfcb) (#1168)
  * Test the codebase with python3.8 beta on tox and travis-ci (#1206), thanks to [@mihrab34](https://github.com/mihrab34)
  * Add a [CODE\_OF\_CONDUCT.md](https://github.com/audreyr/cookiecutter/blob/master/CODE_OF_CONDUCT.md) file to the project, thanks to [@andreagrandi](https://github.com/andreagrandi) (#1009)
  * Update docstrings in `cookiecutter/main.py`, `cookiecutter/__init__.py`, and `cookiecutter/log.py` to follow the PEP 257 style guide, thanks to [@meahow](https://github.com/meahow) (#998, #999, #1000)
  * Update docstrings in `cookiecutter/utils.py` to follow the PEP 257 style guide, thanks to [@dornheimer](https://github.com/dornheimer)(#1026)
  * Fix grammar in *Choice Variables* documentation, thanks to [@jubrilissa](https://github.com/jubrilissa) (#1011)
  * Update installation docs with links to the Windows Subsystem and GNU utilities, thanks to [@Nythiennzo](https://github.com/Nythiennzo) for the PR and [@BruceEckel](https://github.com/BruceEckel) for the review (#1016)
  * Upgrade flake8 to version 3.5.0, thanks to [@cclauss](https://github.com/cclauss) (#1038)
  * Update tutorial with explanation for how cookiecutter finds the template file, thanks to [@accraze](https://github.com/accraze)(#1025)
  * Update CI config files to use `TOXENV` environment variable, thanks to [@asottile](https://github.com/asottile) (#1019)
  * Improve user documentation for writing hooks, thanks to [@jonathansick](https://github.com/jonathansick) (#1057)
  * Make sure to preserve the order of items in the generated cookiecutter context, thanks to [@hackebrot](https://github.com/hackebrot) (#1074)
  * Fixed DeprecationWarning for a regular expression on python 3.6, thanks to [@reinout](https://github.com/reinout) (#1124)
  * Document use of cookiecutter-template topic on GitHub, thanks to [@ssbarnea](https://github.com/ssbarnea) (#1189)
  * Update README badge links, thanks to [@luzfcb](https://github.com/luzfcb) (#1207)
  * Update prompt.py to match pep257 guidelines, thanks to [@jairideout](https://github.com/jairideout) (#1105)
  * Update link to Jinja2 extensions documentation, thanks to [@dacog](https://github.com/dacog) (#1193)
  * Require pip 9.0.0 or newer for tox environments, thanks to [@hackebrot](https://github.com/hackebrot) (#1215)
  * Use io.open contextmanager when reading hook files, thanks to [@jcb91](https://github.com/jcb91) (#1147)
  * Add more cookiecutter templates to the mix:
  * [cookiecutter-python-cli](https://github.com/xuanluong/cookiecutter-python-cli) by [@xuanluong](https://github.com/xuanluong) (#1003)
  * [cookiecutter-docker-science](https://github.com/docker-science/cookiecutter-docker-science) by [@takahi-i](https://github.com/takahi-i) (#1040)
  * [cookiecutter-flask-skeleton](https://github.com/realpython/cookiecutter-flask-skeleton) by [@mjhea0](https://github.com/mjhea0) (#1052)
  * [cookiecutter-awesome](https://github.com/Pawamoy/cookiecutter-awesome) by [@Pawamoy](https://github.com/Pawamoy) (#1051)
  * [cookiecutter-flask-ask](https://github.com/chrisvoncsefalvay/cookiecutter-flask-ask) by [@machinekoder](https://github.com/machinekoder) (#1056)
  * [cookiecutter-data-driven-journalism](https://github.com/jastark/cookiecutter-data-driven-journalism) by [@JAStark](https://github.com/JAStark) (#1020)
  * [cookiecutter-tox-plugin](https://github.com/tox-dev/cookiecutter-tox-plugin) by [@obestwalter](https://github.com/obestwalter) (#1103)
  * [cookiecutter-django-dokku](https://github.com/mashrikt/cookiecutter-django-dokku) by [@mashrikt](https://github.com/mashrikt) (#1093)
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with new click cookiecutter-click7.patch
* Wed Feb 21 2018 sebix@sebix.at
-  update to version 1.6.0:
  * Include template path or template URL in cookiecutter context under _template
  * Add a URL abbreviation for GitLab template projects
  * Add option to use templates from Zip files or Zip URLs
  * bugfixes
- update to version 1.5.1:
  * bugfixes
- remove fix-caplog-tests.diff, it broke the tests
- remove separate specfile for docs, use one combined
* Fri Feb  3 2017 hpj@urpla.net
- version 1.5.0: initial build
